@@ -1,5 +1,5 @@
 import httpx
-from decorators import extract_data_async
+from .decorators import extract_data_async
 
 class Base:
     def __init__(self, base_url: str):
